/********************************************************************
 *
 * Image Acquisition Example
 *
 *
 * Note for ORemoteCamera users:
 * please compile with -DOREMOTECAMERA in order to link it against
 * the ORemotecamera linux library. If you compile it for Windows you
 * don't need to provide this preprocessor switch.
 *
 ********************************************************************/

#ifdef WIN32
  #ifndef OREMOTECAMERA
    #define OREMOTECAMERA
  #endif
#endif

#ifdef OREMOTECAMERA
  #include "OCamera_remote.h"
#else
  #include "OCamera.h"
#endif

#include <iostream>
#include <string>

#ifdef WIN32
#include <conio.h>
#endif

#define CHECK_LOG( mes, value ) { int error = value; \
  if( error != 0 ) std::cerr << "ERROR: " << error << " "  << mes << std::endl;\
else std::cerr << mes << std::endl; }

int main(int argc, char* argv[])
{

  OCamera* oc;

#ifdef OREMOTECAMERA
  std::string sRemoteHost( "192.168.7.10:8080" );
  if(argc > 1)
  {
    sRemoteHost = argv[1];
  }
#endif

#ifdef OREMOTECAMERA
  oc = CreateCameraInterface( OCamera::CAM_TYPE_MT9V403, sRemoteHost.c_str() );
#else
  oc = OCameraCameraInterface::poCreateInterface();
#endif

  if( NULL != oc )
  {
    CHECK_LOG( "Open", oc->Open( 640 * 480 * 4 ) );
    CHECK_LOG( "SetCameraWindow", oc->SetCameraWindow( 0, 0, 640, 480 ) );
    CHECK_LOG( "SetFrequency", oc->SetFrequency( OCamera::FREQU_60MHz ) );
    CHECK_LOG( "SetShutterTime", oc->SetShutterTime( 20000 ) );
    CHECK_LOG( "SetIlluminationMode", oc->SetIlluminationMode( OCamera::ILL_MODE_OFF ) );
    CHECK_LOG( "SetTriggerSource", oc->SetTriggerSource( OCamera::TRIG_SRC_SOFTWARE ) );
    CHECK_LOG( "SetGain", oc->SetGain( 5 ) );
    CHECK_LOG( "SetReadTimeout", oc->SetReadTimeout( 2000000 ) );
    CHECK_LOG( "SetFrameRate", oc->SetFrameRate( 10 ) );
    CHECK_LOG( "SetHardwareApplet", oc->SetHardwareApplet( false, 640 * 480 ) );
    CHECK_LOG( "SetJPEG", oc->SetJPEG( false ) );
    CHECK_LOG( "SetAcquisitionMode", oc->SetAcquisitionMode( OCamera::ACQ_MODE_SINGLE_SHOT ) );

    OCameraImage img;
    img.pData = NULL;
    for( unsigned int i = 0; i < 10; ++i )
    {
      CHECK_LOG( "GetImage", oc->GetImage( &img ) );
      std::cerr << img.nSize << std::endl;
      CHECK_LOG( "ReleaseImage", oc->ReleaseImage( &img ) );
    }
    oc->Close();
    oc->Destroy();
  }
  else
  {
    std::cerr << "Could not open interface" << std::endl;
  }
  #ifdef WIN32
  std::cerr << "please press a key" << std::endl;
  _getch();
  #endif
  return 0;
}

